==> cumulative-0.0.26.tar.gz: cumulative-0.0.26/README.md <==
<p align="center">
<img width="50%" height="50%" src="https://elehcimd.github.io/cumulative/assets/img/logo-black.svg" alt="CUMULATIVE Logo">
</p>

<p align="center">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/test.svg" alt="Test">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/coverage.svg" alt="Coverage">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/python.svg" alt="Python">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/pypi.svg" alt="PyPi">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/license.svg" alt="License">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/code-style.svg" alt="Code style">
</p>

---

**Cumulative** is an open source project and Python package that provides an intuitive in-memory interface to transform and analyse large collections of time series with composable pipelines.

---

* **Documentation**: [https://elehcimd.github.io/cumulative/](https://elehcimd.github.io/cumulative/)
* **Source code**: [https://github.com/elehcimd/cumulative](https://github.com/elehcimd/cumulative)

---

## Key features

* **Transformations**: Apply vectorized time series transformations as composable pipelines
* **Interoperability**: Access the underlying data at any time as a Pandas data frame
* **Flexibility**: Implement custom transformations and store arbitrary metadata

## Requirements

* **Python >=3.10**

## Installation

```
pip install cumulative
```

## License

This project is licensed under the terms of the [BSD 3-Clause License](https://elehcimd.github.io/cumulative/license/).

==> cumulative-0.0.29.tar.gz: cumulative-0.0.29/README.md <==
<p align="center">
<img width="50%" height="50%" src="https://elehcimd.github.io/cumulative/assets/img/logo-black.svg" alt="CUMULATIVE Logo">
</p>

<p align="center">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/test.svg" alt="Test">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/coverage.svg" alt="Coverage">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/python.svg" alt="Python">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/pypi.svg" alt="PyPi">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/license.svg" alt="License">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/code-style.svg" alt="Code style">
</p>

---

**Cumulative** is an open source project and Python package that provides an intuitive in-memory interface to transform and analyse large collections of time series with composable pipelines.

---

* **Documentation**: [https://elehcimd.github.io/cumulative/](https://elehcimd.github.io/cumulative/)
* **Source code**: [https://github.com/elehcimd/cumulative](https://github.com/elehcimd/cumulative)

---

## Key features

* **Transformations**: Apply vectorized time series transformations as composable operations
* **Interoperability**: Access the underlying data at any time as a Pandas data frame
* **Flexibility**: Implement custom transformations and store arbitrary metadata

## Requirements

* **Python >=3.10**

## Installation

```
pip install cumulative
```

## License

This project is licensed under the terms of the [BSD 3-Clause License](https://elehcimd.github.io/cumulative/license/).
